:mod:`euphorie.content.countrymanager`
======================================

.. automodule:: euphorie.content.countrymanager


Interfaces
----------

.. autointerface:: ICountryManager


Functions
---------

.. autofunction:: SearchableTextIndexer


Account support
---------------

.. autoclass:: CountryManagerLocalRoleProvider
   :members:

